#! /bin/sh
#
# script to install this mpack.
#

vchk() \
{
	basename=$1
	fullname=`basename $2`

	./vchk.pl $basename $fullname > /dev/null 2>&1
	ret=$?
	return $ret
}

LOG=/var/tmp/install.output
# rm -f $LOG

echo "Beginning installation of volutionmsg-1.1.1 Update"
echo "Beginning installation of volutionmsg-1.1.1 Update" >> $LOG
date >> $LOG

# volution should be installed.
rpm -qa | grep 'volutionmsg-1\.' > /dev/null || {
	echo "Volution Messaging Server 1.x must be installed prior to this mpack"
	echo "Volution Messaging Server 1.x must be installed prior to this mpack" >> $LOG
	exit
}

rpm -qa | grep volutionmsg-mpack > /dev/null && {
	# remove old mpack
	rpm -e volutionmsg-mpack >> $LOG 2>&1
}

# intelligent version checking here.

vchk cyrus-sasl cyrus-sasl* && {
	rpm -e cyrus-sasl >> $LOG 2>&1
	rpm -i cyrus-sasl* >> $LOG 2>&1
}

vchk horde horde* && {
	rpm -e horde >> $LOG 2>&1
	rpm -i hord* >> $LOG 2>&1
}

vchk imp imp* && {
	rpm -e imp >> $LOG 2>&1
	rpm -i imp* >> $LOG 2>&1
}

vchk drac drac* && {
	rpm -U drac* >> $LOG 2>&1
}
vchk cyrus-imap cyrus-imap* && {
	rpm --force -U --noscripts cyrus-imap* >> $LOG 2>&1
}

# the old postfix version postfix-20010228-1 is too badly formed as a name
# to pass this simple version check.
rpm --force -U postfix* >> $LOG 2>&1

# install or upgade language packs for ispell (useless without these).
for i in ispell-*.rpm; do
	rpm -U $i >> $LOG 2>&1
done

vchk volutionmsg volutionmsg-1* && {
	rpm --force -U volutionmsg-1* >> $LOG 2>&1
}

vchk volutionmsg-doc volutionmsg-doc* && {
	rpm -e volutionmsg-doc >> $LOG 2>&1
	rpm --force -U volutionmsg-doc* >> $LOG 2>&1
}

# Remove session_path from php.ini
if grep -q 'lsb-caldera.com-volution/msg/tmp' /etc/httpd/php.ini ; then
	grep -v '^;.*MESSAGING.*$' /etc/httpd/php.ini | \
	grep -v '^session.save_path.*lsb-caldera.com-volution/msg/tmp' | \
	sed 's%^\;session.save_path%session.save_path%' > /var/tmp/php.ini && \
	mv -f /var/tmp/php.ini /etc/httpd/php.ini
fi

# reconfigure imp
/opt/lsb-caldera.com-volution/msg/bin/msgimpsetup >> $LOG 2>&1

# restore ownership of slapd.conf to original owner 525665:1
SAVEDIR=/etc/opt/lsb-caldera.com-volution/msg/save
OLDOWNER=$(ls -l ${SAVEDIR}/slapd.conf | awk '{print $3 ":" $4}')
chown $OLDOWNER /etc/ldap/slapd.conf >> $LOG 2>&1

# restart services
/etc/rc.d/init.d/postfix stop >> $LOG 2>&1
/etc/rc.d/init.d/cyrus stop >> $LOG 2>&1
/etc/rc.d/init.d/ldap stop >> $LOG 2>&1

/etc/rc.d/init.d/ldap start >> $LOG 2>&1
/etc/rc.d/init.d/cyrus start >> $LOG 2>&1
/etc/rc.d/init.d/postfix start >> $LOG 2>&1

echo "Installation of volutionmsg-1.1.1 Update completed"
echo "Installation of volutionmsg-1.1.1 Update completed" >> $LOG
